==> manage-1.1.32-2.jar: management/sqls/营收/报表管理/统计类/收费统计汇总表/get_curcollect.sql <==
//本期实际收费情况
select
	s1.f_price_id,
	s.f_gasproperties_type,
	s.f_gasproperties,
	convert(decimal(18,2),SUM(f_gas1)+SUM(f_gas2)+SUM(f_gas3)) f_pregas,
	convert(decimal(18,2),SUM(f_money1)+SUM(f_money2)+SUM(f_money3)) f_collection,
	convert(decimal(18,2),SUM(f_gas1)) f_pregas1,
	convert(decimal(18,2),SUM(f_money1)) f_collection1,
	convert(decimal(18,2),SUM(f_gas2)) f_pregas2,
	convert(decimal(18,2),SUM(f_money2)) f_collection2,
	convert(decimal(18,2),SUM(f_gas3)) f_pregas3,
	convert(decimal(18,2),SUM(f_money3)) f_collection3
from (	
		select 
			f_price_id,
			SUM(f_gas1) f_gas1,
			SUM(f_money1) f_money1,
			SUM(f_gas2) f_gas2,
			SUM(f_money2) f_money2,
			SUM(f_gas3) f_gas3,
			SUM(f_money3) f_money3
		from(	
			select
				f_price_id,
				case when f_price_name='阶梯1' or f_price_name='固定气价' then f_gas else 0 end f_gas1,
				case when f_price_name='阶梯1' or f_price_name='固定气价' then 
				(case when f_money=0 then f_gas*1.98 else f_money end) else 0 end f_money1,
				case when f_price_name='阶梯2' then f_gas else 0 end f_gas2,
				case when f_price_name='阶梯2' then (case when f_money=0 then f_gas*1.98 else f_money end) else 0 end f_money2,
				case when f_price_name='阶梯3' then f_gas else 0 end f_gas3,
				case when f_price_name='阶梯3' then (case when f_money=0 then f_gas*1.98 else f_money end) else 0 end f_money3
			from t_chargeprice c 
			left join t_sellinggas s on c.f_charge_id=s.id 
			where  f_charge_id in (
				select 
					id
				from t_sellinggas 
				where f_charge_state='有效' and f_delivery_date>='{startDate}'
					  and f_delivery_date<='{endDate}' 
			)
		) p group by f_price_id
	) s1 left join 
	(select * from t_stairprice where f_state='有效') s 
	on s1.f_price_id=s.f_price_id
	group by s1.f_price_id,s.f_gasproperties_type,s.f_gasproperties

==> manage-3.1.0-40.jar: management/sqls/营收/报表管理/统计类/收费统计汇总表/get_curcollect.sql <==
//本期实际收费情况
select
	s1.f_price_id,
	s.f_gasproperties_type,
	s.f_gasproperties,
	convert(decimal(18,2),SUM(f_gas1)+SUM(f_gas2)+SUM(f_gas3)) f_pregas,
	convert(decimal(18,2),SUM(f_money1)+SUM(f_money2)+SUM(f_money3)) f_collection,
	convert(decimal(18,2),SUM(f_gas1)) f_pregas1,
	convert(decimal(18,2),SUM(f_money1)) f_collection1,
	convert(decimal(18,2),SUM(f_gas2)) f_pregas2,
	convert(decimal(18,2),SUM(f_money2)) f_collection2,
	convert(decimal(18,2),SUM(f_gas3)) f_pregas3,
	convert(decimal(18,2),SUM(f_money3)) f_collection3
from (	
		select 
			f_price_id,
			SUM(f_gas1) f_gas1,
			SUM(f_money1) f_money1,
			SUM(f_gas2) f_gas2,
			SUM(f_money2) f_money2,
			SUM(f_gas3) f_gas3,
			SUM(f_money3) f_money3
		from(	
			select
				f_price_id,
				case when f_price_name='阶梯1' or f_price_name='固定气价' then f_gas else 0 end f_gas1,
				case when f_price_name='阶梯1' or f_price_name='固定气价' then 
				(case when f_money=0 then f_gas*1.98 else f_money end) else 0 end f_money1,
				case when f_price_name='阶梯2' then f_gas else 0 end f_gas2,
				case when f_price_name='阶梯2' then (case when f_money=0 then f_gas*1.98 else f_money end) else 0 end f_money2,
				case when f_price_name='阶梯3' then f_gas else 0 end f_gas3,
				case when f_price_name='阶梯3' then (case when f_money=0 then f_gas*1.98 else f_money end) else 0 end f_money3
			from t_chargeprice c 
			left join t_sellinggas s on c.f_charge_id=s.id 
			where  f_charge_id in (
				select 
					id
				from t_sellinggas 
				where f_state='有效' and f_operate_date>='{startDate}'
					  and f_operate_date<='{endDate}'
			)
		) p group by f_price_id
	) s1 left join 
	(select * from t_stairprice where f_state='有效') s 
	on s1.f_price_id=s.f_price_id
	group by s1.f_price_id,s.f_gasproperties_type,s.f_gasproperties
